
:autogenerated:

weylchamber.perfect_entanglers module
=====================================

.. currentmodule:: weylchamber.perfect_entanglers

.. automodule:: weylchamber.perfect_entanglers
    :members: F_PE, concurrence, make_PE_krotov_chi_constructor, pi, project_to_PE, sin
    :undoc-members:
    :show-inheritance:
    :member-order: bysource

    Summary
    -------

    Functions:

    .. autosummary::
        :nosignatures:

        F_PE
        concurrence
        make_PE_krotov_chi_constructor
        project_to_PE





    ``__all__``: :func:`F_PE <weylchamber.perfect_entanglers.F_PE>`, :func:`concurrence <weylchamber.perfect_entanglers.concurrence>`, :func:`make_PE_krotov_chi_constructor <weylchamber.perfect_entanglers.make_PE_krotov_chi_constructor>`, :func:`project_to_PE <weylchamber.perfect_entanglers.project_to_PE>`



    Reference
    ---------